@@ -13,6 +13,7 @@ const file_input = {
     ,
   init: function(opts) {
     var io = this;
+    this.file_count = opts.file_count;
     this.target.find(".upload_zone").click(function (e) {
       io.target.find(".hidden_upload").click();
     });
@@ -25,6 +26,12 @@ const file_input = {
       files = e.originalEvent.dataTransfer.files;
       io.load_preview_from_files(files)
     });
+    if (this.file_count == "multiple") {
+      this.target.find(".hidden_upload").attr("multiple", "true");
+    } else if (this.file_count == "directory") {
+      this.target.find(".hidden_upload").attr("webkitdirectory", "true");
+      this.target.find(".hidden_upload").attr("mozdirectory", "true");
+    }
     this.target.find('.hidden_upload').on('change', function (e) {
       if (this.files) {
         io.load_preview_from_files(this.files);
@@ -40,26 +47,48 @@ const file_input = {
     var io = this;
     io.target.find(".upload_zone").hide();
     io.target.find(".file_display").removeClass("hide");
-    io.target.find(".file_name").text(io.file_data.name);
-    if (io.file_data.size !== null) {
-      io.target.find(".file_size").text(prettyBytes(io.file_data.size));
+    if (io.file_count == "single") {
+      io.target.find(".file_name").text(io.file_data[0].name);
+      if (io.file_data[0].size !== null) {
+        io.target.find(".file_size").text(prettyBytes(io.file_data[0].size));
+      }
+    } else {
+      io.target.find(".file_name").text(io.file_data.length + " files");
+      let total_bytes = 0;
+      for (let file of io.file_data) {
+        if (file.size == null) {
+          total_bytes = null;
+          break;
+        } else {
+          total_bytes += file.size;
+        }
+      }
+      if (total_bytes != null) {
+        io.target.find(".file_size").text(prettyBytes(total_bytes));
+      }
     }
   },
   load_preview_from_files: function(files) {
     if (!files.length || !window.FileReader) {
       return
     }
-    var ReaderObj = new FileReader()
-    ReaderObj.readAsDataURL(files[0])
+
     var io = this;
-    ReaderObj.onloadend = function() {
-      io.file_data = {
-        "name": files[0].name,
-        "size": files[0].size,
-        "data": this.result,
-        "is_local_example": false
+    io.file_data = [];
+    for (let file of files) {
+      let ReaderObj = new FileReader()
+      ReaderObj.readAsDataURL(file)
+      ReaderObj.onloadend = function() {
+        io.file_data.push({
+          "name": file.name,
+          "size": file.size,
+          "data": this.result,
+          "is_local_example": false
+        });
+        if (io.file_data.length == files.length) {
+          io.load_preview();
+        }
       }
-      io.load_preview()
     };
   },
   load_example: function(example_data) {
