@@ -11,7 +11,7 @@ const textbox_output = {
     this.target.find(".output_text").empty();
   },
   load_example_preview: function(data) {
-    if (data.length > 20) {
+    if (typeof data == "string" && data.length > 20) {
       return data.substring(0,20) + "...";
     }
     return data;
