@@ -20,8 +20,13 @@ const video_output = {
     this.target.find(".output_image_holder").addClass("hide");
     this.target.find(".output_image").attr('src', "")
   },
-  load_example_preview: function(data) {
-    return "<video controls src='"+data[0]+"' height=100>"
-  },
-
+  load_example: function(example_data) {
+    example_data = this.io_master.example_file_path + example_data;
+    let io = this;
+    toDataURL(example_data, function(data) {
+      io.target.find(".upload_zone").hide();
+      io.target.find(".image_display").removeClass("hide");
+      io.output(data);
+    })
+  }
 }
